@@ -1,6 +1,6 @@
 #' @title Test the effect of phylogenetic uncertainty on rate shifts found at a particular node
 #' @description The function uses a number of alternative phylogenies with altered (as compared to the reference tree) topology and branch lengths tests whether the tips descending from the specified node (\code{node}) have statistically different rates from the rest of the tree. A phenotypic vector \code{y} must be supplied. Eventually, the effect of a covariate could be included.
-#' @usage swap.phylo(tree,si=0.5,si2=0.5,node,y,rts,nrep=100,cov=NULL)
+#' @usage swap.phylo(tree,si=0.5,si2=0.5,node,y,rts,nrep=100,cov=NULL,clus=0.5)
 #' @param tree a phylogenetic tree. The tree needs not to be ultrametric or fully dichotomous.
 #' @param si the proportion of tips whose topologic arrangement will be swapped.
 #' @param si2 the proportion of nodes whose age will be changed.
@@ -9,6 +9,7 @@
 #' @param rts the rates found by \code{\link{RRphylo}} on the original tree.
 #' @param nrep the number of simulated trees to be produced.
 #' @param cov the covariate to be indicated if its effect on rate values must be accounted for. Contrary to \code{RRphylo}, \code{cov} needs to be as long as the number of tips of the tree.
+#' @param clus the proportion of clusters to be used in parallel computing (only if \code{y} is multivariate).
 #' @importFrom graphics hist par
 #' @importFrom grDevices rgb
 #' @importFrom stats t.test
@@ -18,30 +19,31 @@
 #' @return \strong{$p.swap} the probability that the rates at \code{node} are different from rates at the rest of the tree.
 #' @return \strong{$rates} the distribution of rates per branch as calculated by \code{RRphylo} on 'swapped' phylogenies.
 #' @examples
+#' \dontrun{
 #'   data("DataApes")
 #'   DataApes$PCstage->PCstage
 #'   DataApes$Tstage->Tstage
 #'   DataApes$CentroidSize->CS
+#'   cc<- 2/parallel::detectCores()
 #'
-#' \donttest{
 #' # Case 1. swap.phylo without accounting for the effect of a covariate
-#'   RRphylo(tree=Tstage,y=PCstage)->RR
+#'   RRphylo(tree=Tstage,y=PCstage,clus=cc)->RR
 #'   RR$rates->rr
-#'   swap.phylo(Tstage,node=61,y=PCstage,rts=rr)
-
+#'   swap.phylo(Tstage,node=61,y=PCstage,rts=rr,clus=cc)
+#'
 #' # Case 2. swap.phylo accounting for the effect of a covariate
-#'   RRphylo(tree=Tstage,y=CS)->RRcova
+#'   RRphylo(tree=Tstage,y=CS,clus=cc)->RRcova
 #'   c(RRcova$aces,CS)->cov.values
 #'   c(rownames(RRcova$aces),names(CS))->names(cov.values)
-#'   RRphylo(tree=Tstage,y=PCstage,cov=cov.values)->RR
+#'   RRphylo(tree=Tstage,y=PCstage,cov=cov.values,clus=cc)->RR
 #'   RR$rates->rr
-#'   swap.phylo(Tstage,node=61,y=PCstage,rts=rr,cov=CS)
+#'   swap.phylo(Tstage,node=61,y=PCstage,rts=rr,cov=CS,clus=cc)
 #' }
 
 
 
 
-swap.phylo<-function(tree,si=0.5,si2=0.5,node,y,rts,nrep=100,cov=NULL){
+swap.phylo<-function(tree,si=0.5,si2=0.5,node,y,rts,nrep=100,cov=NULL,clus=0.5){
 
     maxN <- function(x, N=2){
       len <- length(x)
@@ -53,16 +55,17 @@ swap.phylo<-function(tree,si=0.5,si2=0.5,node,y,rts,nrep=100,cov=NULL){
     }
 
     tree->tree1
-    if(class(y)=="data.frame") treedata(tree,y,sort=TRUE)[[2]]->y
+    #if(inherits(y,"data.frame")) treedata(tree,y,sort=TRUE)[[2]]->y
+    if(is.null(nrow(y))) y <- treedata(tree, y, sort = TRUE)[[2]][,1] else y <- treedata(tree, y, sort = TRUE)[[2]]
     Rrts<-list()
     if(is.null(cov))
     {
-      replicate(nrep,RRphylo(swapONE(tree,si,si2,plot.swap=FALSE)[[1]],y)$rates)->Rrts
+      replicate(nrep,RRphylo(swapONE(tree,si,si2,plot.swap=FALSE)[[1]],y,clus=clus)$rates)->Rrts
     }else{
       RRphylo(tree,cov)->RRcov
       c(RRcov$aces,cov)->cova
       names(cova)<-c(rownames(RRcov$aces),names(cov))
-      replicate(nrep,RRphylo(swapONE(tree,si,si2,plot.swap=FALSE)[[1]],y,cov=cova)$rates)->Rrts
+      replicate(nrep,RRphylo(swapONE(tree,si,si2,plot.swap=FALSE)[[1]],y,cov=cova,clus=clus)$rates)->Rrts
     }
 
     for(i in 1:dim(Rrts)[3]) Rrts[,,i][match(rownames(rts),names(Rrts[,,i]))]
